@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2012 Leandro Nini
+ * Copyright 2011-2014 Leandro Nini
  * Copyright 2000 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,8 @@
 #ifndef INICONFIG_H
 #define INICONFIG_H
 
-#include "ini/libini.h"
+#include "ini/types.h"
+#include "ini/iniHandler.h"
 
 #include <sidplayfp/SidConfig.h>
 
@@ -35,12 +36,12 @@ public:
     struct sidplay2_section
     {
         int            version;
-        char          *database;
+        SID_STRING     database;
         uint_least32_t playLength;
         uint_least32_t recordLength;
-        char          *kernalRom;
-        char          *basicRom;
-        char          *chargenRom;
+        SID_STRING     kernalRom;
+        SID_STRING     basicRom;
+        SID_STRING     chargenRom;
     };
 
     struct console_section
@@ -65,7 +66,7 @@ public:
 
     struct emulation_section
     {   // INI Section - [Emulation]
-        char         *engine;
+        SID_STRING    engine;
         SidConfig::c64_model_t  modelDefault;
         bool          modelForced;
         SidConfig::sid_model_t  sidModel;
@@ -77,8 +78,8 @@ public:
     };
 
 protected:
-    static const char *DIR_NAME;
-    static const char *FILE_NAME;
+    static const TCHAR *DIR_NAME;
+    static const TCHAR *FILE_NAME;
 
     bool      status;
     struct    sidplay2_section  sidplay2_s;
@@ -89,17 +90,17 @@ protected:
 protected:
     void  clear ();
 
-    bool  readInt    (ini_fd_t ini, const char *key, int &value);
-    bool  readDouble (ini_fd_t ini, const char *key, double &value);
-    bool  readString (ini_fd_t ini, const char *key, char *&str);
-    bool  readBool   (ini_fd_t ini, const char *key, bool &boolean);
-    bool  readChar   (ini_fd_t ini, const char *key, char &ch);
-    bool  readTime   (ini_fd_t ini, const char *key, int  &time);
+    static bool readInt    (iniHandler &ini, const TCHAR *key, int &value);
+    static bool readDouble (iniHandler &ini, const TCHAR *key, double &value);
+    static bool readString (iniHandler &ini, const TCHAR *key, SID_STRING &str);
+    static bool readBool   (iniHandler &ini, const TCHAR *key, bool &boolean);
+    static bool readChar   (iniHandler &ini, const TCHAR *key, char &ch);
+    static bool readTime   (iniHandler &ini, const TCHAR *key, int  &time);
 
-    bool  readSidplay2  (ini_fd_t ini);
-    bool  readConsole   (ini_fd_t ini);
-    bool  readAudio     (ini_fd_t ini);
-    bool  readEmulation (ini_fd_t ini);
+    bool readSidplay2  (iniHandler &ini);
+    bool readConsole   (iniHandler &ini);
+    bool readAudio     (iniHandler &ini);
+    bool readEmulation (iniHandler &ini);
 
 public:
     IniConfig  ();
@@ -109,10 +110,10 @@ public:
     operator bool () { return status; }
 
     // Sidplayfp Specific Section
-    const sidplay2_section&  sidplay2     () { return sidplay2_s; }
-    const console_section&   console      () { return console_s; }
-    const audio_section&     audio        () { return audio_s; }
-    const emulation_section& emulation    () { return emulation_s; }
+    const sidplay2_section&  sidplay2  () { return sidplay2_s; }
+    const console_section&   console   () { return console_s; }
+    const audio_section&     audio     () { return audio_s; }
+    const emulation_section& emulation () { return emulation_s; }
 };
 
 #endif // INICONFIG_H
