@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2013 Leandro Nini
+ * Copyright 2011-2015 Leandro Nini
  * Copyright 2000-2001 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,8 @@
 #include <climits>
 #include <cstdlib>
 
+#include "ini/types.h"
+
 using std::cout;
 using std::cerr;
 using std::endl;
@@ -35,6 +37,34 @@ using std::endl;
 #  include <sidplayfp/builders/hardsid.h>
 #endif
 
+/**
+ * Try load SID tune from HVSC_BASE
+ */
+bool ConsolePlayer::tryOpenTune(const char *hvscBase)
+{
+    std::string newFileName(hvscBase);
+
+    newFileName.append(SEPARATOR).append(m_filename);
+    m_tune.load(newFileName.c_str());
+    if (!m_tune.getStatus())
+    {
+        return false;
+    }
+
+    m_filename.assign(newFileName);
+    return true;
+}
+
+/**
+ * Try load songlength DB from HVSC_BASE
+ */
+bool ConsolePlayer::tryOpenDatabase(const char *hvscBase)
+{
+    std::string newFileName(hvscBase);
+
+    newFileName.append(SEPARATOR).append("DOCUMENTS").append(SEPARATOR).append("Songlengths.txt");
+    return m_database.open(newFileName.c_str());
+}
 
 // Convert time from integer
 bool ConsolePlayer::parseTime (const char *str, uint_least32_t &time)
@@ -92,8 +122,10 @@ int ConsolePlayer::args (int argc, const char *argv[])
     m_driver.output = OUT_SOUNDCARD;
     m_driver.file   = false;
 
-    v1mute = v2mute = v3mute = false;
-    v4mute = v5mute = v6mute = false;
+    for (int i=0; i<9; i++)
+    {
+        vMute[i] = false;
+    }
 
     int  infile = 0;
     int  i      = 0;
@@ -126,6 +158,13 @@ int ConsolePlayer::args (int argc, const char *argv[])
                 if (!parseAddress (&argv[i][3], m_engCfg.secondSidAddress))
                     err = true;
             }
+#if LIBSIDPLAYFP_VERSION_MAJ > 1 || LIBSIDPLAYFP_VERSION_MIN >= 8
+            else if (strncmp (&argv[i][1], "ts", 2) == 0)
+            {   // Override sidTune and enable the third sid
+                if (!parseAddress (&argv[i][3], m_engCfg.thirdSidAddress))
+                    err = true;
+            }
+#endif
             else if (argv[i][1] == 'f')
             {
                 if (argv[i][2] == '\0')
@@ -172,15 +211,8 @@ int ConsolePlayer::args (int argc, const char *argv[])
                 else
                 {
                     const int voice = atoi(&argv[i][2]);
-                    switch (voice)
-                    {
-                    case 1: v1mute = true; break;
-                    case 2: v2mute = true; break;
-                    case 3: v3mute = true; break;
-                    case 4: v4mute = true; break;
-                    case 5: v5mute = true; break;
-                    case 6: v6mute = true; break;
-                    }
+                    if (voice > 0 && voice <= 9)
+                        vMute[voice-1] = true;
                 }
             }
 
@@ -380,13 +412,21 @@ int ConsolePlayer::args (int argc, const char *argv[])
         i++;  // next index
     }
 
+    const char* hvscBase = getenv("HVSC_BASE");
+
     // Load the tune
     m_filename = argv[infile];
-    m_tune.load (m_filename);
+    m_tune.load(m_filename.c_str());
     if (!m_tune.getStatus())
     {
-        displayError (m_tune.statusString());
-        return -1;
+        std::string errorString(m_tune.statusString());
+
+        // Try prepending HVSC_BASE
+        if (!hvscBase || !tryOpenTune(hvscBase))
+        {
+            displayError(errorString.c_str());
+            return -1;
+        }
     }
 
     // If filename specified we can only convert one song
@@ -425,21 +465,25 @@ int ConsolePlayer::args (int argc, const char *argv[])
             if (m_driver.file)
                 m_timer.length = (m_iniCfg.sidplay2()).recordLength;
 
+            if (!hvscBase || !tryOpenDatabase(hvscBase))
+            {
+                // Try load user configured songlength DB
 #if defined(WIN32) && defined(UNICODE)
-            // FIXME
-            char database[MAX_PATH];
-            int ret = wcstombs(database, (m_iniCfg.sidplay2()).database.c_str(), sizeof(database));
-            if (ret >= MAX_PATH)
-                database[0] = '\0';
+                // FIXME
+                char database[MAX_PATH];
+                const int ret = wcstombs(database, (m_iniCfg.sidplay2()).database.c_str(), sizeof(database));
+                if (ret >= MAX_PATH)
+                    database[0] = '\0';
 #else
-            const char *database = (m_iniCfg.sidplay2()).database.c_str();
+                const char *database = (m_iniCfg.sidplay2()).database.c_str();
 #endif
-            if (strlen(database) != 0)
-            {   // Try loading the database specificed by the user
-                if (!m_database.open (database))
-                {
-                    displayError (m_database.error ());
-                    return -1;
+                if (strlen(database) != 0)
+                {   // Try loading the database specificed by the user
+                    if (!m_database.open(database))
+                    {
+                        displayError (m_database.error ());
+                        return -1;
+                    }
                 }
             }
         }
@@ -455,7 +499,7 @@ int ConsolePlayer::args (int argc, const char *argv[])
 #endif
 
     // Configure engine with settings
-    if (m_engine.config (m_engCfg) < 0)
+    if (!m_engine.config (m_engCfg))
     {   // Config failed
         displayError (m_engine.error ());
         return -1;
@@ -481,6 +525,9 @@ void ConsolePlayer::displayArgs (const char *arg)
         << " -f<num>      set frequency in Hz (default: "
         << SidConfig::DEFAULT_SAMPLING_FREQ << ")" << endl
         << " -ds<addr>    set second sid address (e.g. -ds0xd420)" << endl
+#if LIBSIDPLAYFP_VERSION_MAJ > 1 || LIBSIDPLAYFP_VERSION_MIN >= 8
+        << " -ts<addr>    set third sid address (e.g. -ts0xd440)" << endl
+#endif
 
         << " -u<num>      mute voice <num> (e.g. -u1 -u2)" << endl
 
