@@ -21,20 +21,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <stdlib.h>
-#include <vector>
 #include "WavFile.h"
-#include "WavFileDefs.h"
 
-#ifdef WAV_HAVE_EXCEPTIONS
-#   include <new>
-#endif
-
-#ifdef WAV_HAVE_IOS_OPENMODE
-    typedef std::ios::openmode openmode;
-#else
-    typedef int openmode;
-#endif
+#include <vector>
+#include <iomanip>
+#include <fstream>
+#include <new>
 
 // Get the lo byte (8 bit) in a dword (32 bit)
 inline uint8_t endian_32lo8 (uint_least32_t dword)
@@ -92,33 +84,29 @@ const wavHeader WavFile::defaultWavHdr = {
     {0x64,0x61,0x74,0x61}, {0,0,0,0}
 };
 
-WavFile::WavFile()
-: wavHdr(defaultWavHdr),
-  file(0)
-{
-    precision = 32;
-    headerWritten = false;
-}
+WavFile::WavFile(const char *name) :
+    AudioBase("WAVFILE"),
+    name(name),
+    wavHdr(defaultWavHdr),
+    file(0),
+    headerWritten(false),
+    precision(32)
+{}
 
-short* WavFile::open(AudioConfig &cfg, const char* name)
+bool WavFile::open(AudioConfig &cfg)
 {
-    unsigned long  int freq;
-    unsigned short int channels, bits, format;
-    unsigned short int blockAlign;
-    unsigned long  int bufSize;
-
     precision = cfg.precision;
 
-    bits        = precision;
-    format      = (precision == 16 ) ? 1 : 3;
-    channels    = cfg.channels;
-    freq        = cfg.frequency;
-    blockAlign  = (bits>>3)*channels;
-    bufSize     = freq * blockAlign;
+    unsigned short bits       = precision;
+    unsigned short format     = (precision == 16 ) ? 1 : 3;
+    unsigned short channels   = cfg.channels;
+    unsigned long  freq       = cfg.frequency;
+    unsigned short blockAlign = (bits>>3)*channels;
+    unsigned long  bufSize    = freq * blockAlign;
     cfg.bufSize = bufSize;
 
-    if (name == NULL)
-        return NULL;
+    if (name.empty())
+        return false;
 
     if (file && !file->fail())
         close();
@@ -126,58 +114,62 @@ short* WavFile::open(AudioConfig &cfg, const char* name)
     byteCount = 0;
 
     // We need to make a buffer for the user
-#if defined(WAV_HAVE_EXCEPTIONS)
-    _sampleBuffer = new(std::nothrow) short[bufSize];
-#else
-    _sampleBuffer = new short[bufSize];
-#endif
-    if (!_sampleBuffer)
-        return NULL;
+    try
+    {
+        _sampleBuffer = new short[bufSize];
+    }
+    catch (std::bad_alloc const &ba)
+    {
+        setError("Unable to allocate memory for sample buffers.");
+        return false;
+    }
 
     // Fill in header with parameters and expected file size.
-    endian_little32(wavHdr.length,sizeof(wavHeader)-8);
-    endian_little16(wavHdr.channels,channels);
-    endian_little16(wavHdr.format,format);
-    endian_little32(wavHdr.sampleFreq,freq);
-    endian_little32(wavHdr.bytesPerSec,freq*blockAlign);
-    endian_little16(wavHdr.blockAlign,blockAlign);
-    endian_little16(wavHdr.bitsPerSample,bits);
-    endian_little32(wavHdr.dataChunkLen,0);
+    endian_little32(wavHdr.length, sizeof(wavHeader)-8);
+    endian_little16(wavHdr.channels, channels);
+    endian_little16(wavHdr.format, format);
+    endian_little32(wavHdr.sampleFreq, freq);
+    endian_little32(wavHdr.bytesPerSec, freq*blockAlign);
+    endian_little16(wavHdr.blockAlign, blockAlign);
+    endian_little16(wavHdr.bitsPerSample, bits);
+    endian_little32(wavHdr.dataChunkLen, 0);
 
-    openmode createAttr = std::ios::out;
-#if defined(WAV_HAVE_IOS_BIN)
-    createAttr |= std::ios::bin;
-#else
-    createAttr |= std::ios::binary;
-#endif
-
-    if (strncmp("-", name, 2) == 0) {
+    if (name.compare("-") == 0)
+    {
         file = &std::cout;
-    } else {
-        file = new std::ofstream(name, createAttr|std::ios::trunc);
+    }
+    else
+    {
+        file = new std::ofstream(name.c_str(), std::ios::out|std::ios::binary|std::ios::trunc);
     }
 
     _settings = cfg;
-    return _sampleBuffer;
+    return true;
 }
 
-short* WavFile::write()
+bool WavFile::write()
 {
-    if (file && !file->fail()) {
+    if (file && !file->fail())
+    {
         unsigned long int bytes = _settings.bufSize;
-        if (!headerWritten) {
+        if (!headerWritten)
+        {
             file->write((char*)&wavHdr,sizeof(wavHeader));
             headerWritten = true;
         }
 
         /* XXX endianness... */
-        if (precision == 16) {
+        if (precision == 16)
+        {
             bytes *= 2;
             file->write((char*)_sampleBuffer, bytes);
-        } else {
+        }
+        else
+        {
             std::vector<float> buffer(_settings.bufSize);
             bytes *= 4;
-            for (unsigned long i=0;i<_settings.bufSize;i++) {
+            for (unsigned long i=0;i<_settings.bufSize;i++)
+            {
                 buffer[i] = ((float)_sampleBuffer[i])/32768.f;
             }
             file->write((char*)&buffer.front(), bytes);
@@ -185,17 +177,19 @@ short* WavFile::write()
         byteCount += bytes;
 
     }
-    return _sampleBuffer;
+    return true;
 }
 
 void WavFile::close()
 {
-    if (file && !file->fail()) {
-        endian_little32(wavHdr.length,byteCount+sizeof(wavHeader)-8);
-        endian_little32(wavHdr.dataChunkLen,byteCount);
-        if (file != &std::cout) {
+    if (file && !file->fail())
+    {
+        endian_little32(wavHdr.length, byteCount+sizeof(wavHeader)-8);
+        endian_little32(wavHdr.dataChunkLen, byteCount);
+        if (file != &std::cout)
+        {
             file->seekp(0, std::ios::beg);
-            file->write((char*)&wavHdr,sizeof(wavHeader));
+            file->write((char*)&wavHdr, sizeof(wavHeader));
             delete file;
         }
         file = 0;
