@@ -21,12 +21,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef WAV_FILE_HEADER_H
-#define WAV_FILE_HEADER_H
+#ifndef WAV_FILE_H
+#define WAV_FILE_H
 
 #include <iostream>
-#include <iomanip>
-#include <fstream>
+#include <string>
+
 #include "../AudioBase.h"
 
 struct wavHeader                        // little endian format
@@ -58,6 +58,8 @@ struct wavHeader                        // little endian format
 class WavFile: public AudioBase
 {
 private:
+    std::string name;
+
     unsigned long int byteCount;
 
     static const wavHeader defaultWavHdr;
@@ -68,39 +70,29 @@ private:
     int precision;
 
 public:
+    WavFile(const char *name);
+    ~WavFile() { close(); }
 
-    WavFile();
+    static const char *extension () { return ".wav"; }
 
-    // Only unsigned 8-bit, and signed 16-bit, samples are supported.
+    // Only signed 16-bit and 32bit float samples are supported.
     // Endian-ess is adjusted if necessary.
     //
     // If number of sample bytes is given, this can speed up the
     // process of closing a huge file on slow storage media.
 
-    short *open(AudioConfig &cfg, const char *name);
+    bool open(AudioConfig &cfg);
 
     // After write call old buffer is invalid and you should
     // use the new buffer provided instead.
-    short *write();
-    void  close();
-    void  pause() {;}
-    const char *extension () const { return ".wav"; }
-    ~WavFile() { close(); }
-
-    // Rev 1.3 (saw) - Changed, see AudioBase.h
-    short *reset ()
-    {
-        if (file != 0)
-            return _sampleBuffer;
-        return NULL;
-    }
+    bool write();
+    void close();
+    void pause() {}
+    void reset() {}
 
     // Stream state.
     bool fail() const { return (file->fail() != 0); }
     bool bad()  const { return (file->bad()  != 0); }
-
-    operator bool()  const { return (file->good() != 0); }
-    bool operator!() const { return (file->fail() != 0); }
 };
 
-#endif /* WAVE_FILE_HEADER_H */
+#endif /* WAV_FILE_H */
