@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2013 Leandro Nini
+ * Copyright 2011-2015 Leandro Nini
  * Copyright 2000-2001 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -128,12 +128,10 @@ uint8_t* loadRom(const SID_STRING &romPath, const int size, const TCHAR defaultR
 
 
 ConsolePlayer::ConsolePlayer (const char * const name) :
-    Event("External Timer\n"),
     m_name(name),
     m_tune(0),
     m_state(playerStopped),
     m_outfile(NULL),
-    m_context(NULL),
     m_filename(""),
     m_quietLevel(0),
     m_verboseLevel(0),
@@ -490,12 +488,15 @@ bool ConsolePlayer::open (void)
     m_speed.current   = m_speed.max;
     m_engine.fastForward (100 * m_speed.current);
 
-    m_engine.mute(0, 0, v1mute);
-    m_engine.mute(0, 1, v2mute);
-    m_engine.mute(0, 2, v3mute);
-    m_engine.mute(1, 0, v4mute);
-    m_engine.mute(1, 1, v5mute);
-    m_engine.mute(1, 2, v6mute);
+    m_engine.mute(0, 0, vMute[0]);
+    m_engine.mute(0, 1, vMute[1]);
+    m_engine.mute(0, 2, vMute[2]);
+    m_engine.mute(1, 0, vMute[3]);
+    m_engine.mute(1, 1, vMute[4]);
+    m_engine.mute(1, 2, vMute[5]);
+    m_engine.mute(2, 0, vMute[6]);
+    m_engine.mute(2, 1, vMute[7]);
+    m_engine.mute(2, 2, vMute[8]);
 
     // As yet we don't have a required songlength
     // so try the songlength database
@@ -507,7 +508,6 @@ bool ConsolePlayer::open (void)
     }
 
     // Set up the play timer
-    m_context = m_engine.getEventContext();
     m_timer.stop  = 0;
     m_timer.stop += m_timer.length;
 
@@ -529,7 +529,7 @@ bool ConsolePlayer::open (void)
 
     // Update display
     menu();
-    event();
+    updateDisplay();
     return true;
 }
 
@@ -583,6 +583,8 @@ bool ConsolePlayer::play ()
 {
     if (m_state == playerRunning)
     {
+        updateDisplay();
+
         // Fill buffer
         short *buffer = m_driver.selected->buffer ();
         const uint_least32_t length = m_driver.cfg.bufSize;
@@ -592,7 +594,6 @@ bool ConsolePlayer::play ()
             if (m_engine.isPlaying ())
             {
                 m_state = playerError;
-                return false;
             }
             return false;
         }
@@ -647,52 +648,49 @@ void ConsolePlayer::stop ()
 
 
 // External Timer Event
-void ConsolePlayer::event (void)
+void ConsolePlayer::updateDisplay()
 {
     const uint_least32_t seconds = m_engine.time();
-    if ( !m_quietLevel )
+    if (seconds == m_timer.current)
+        return;
+
+    if (!m_quietLevel)
     {
         cerr << "\b\b\b\b\b" << std::setw(2) << std::setfill('0')
              << ((seconds / 60) % 100) << ':' << std::setw(2)
              << std::setfill('0') << (seconds % 60) << std::flush;
     }
 
-    if (seconds != m_timer.current)
-    {
-        m_timer.current = seconds;
+    m_timer.current = seconds;
 
-        if (seconds == m_timer.start)
-        {   // Switch audio drivers.
-            m_driver.selected = m_driver.device;
-            memset (m_driver.selected->buffer (), 0, m_driver.cfg.bufSize);
-            m_speed.current = 1;
-            m_engine.fastForward (100);
-            if (m_cpudebug)
-                m_engine.debug (true, NULL);
-        }
-        else if (m_timer.stop && (seconds == m_timer.stop))
+    if (seconds == m_timer.start)
+    {   // Switch audio drivers.
+        m_driver.selected = m_driver.device;
+        memset(m_driver.selected->buffer (), 0, m_driver.cfg.bufSize);
+        m_speed.current = 1;
+        m_engine.fastForward(100);
+        if (m_cpudebug)
+            m_engine.debug (true, NULL);
+    }
+    else if (m_timer.stop && (seconds >= m_timer.stop))
+    {
+        m_state = playerExit;
+        for (;;)
         {
-            m_state = playerExit;
-            for (;;)
-            {
-                if (m_track.single)
-                    return;
-                // Move to next track
-                m_track.selected++;
-                if (m_track.selected > m_track.songs)
-                    m_track.selected = 1;
-                if (m_track.selected == m_track.first)
-                    return;
-                m_state = playerRestart;
-                break;
-            }
-            if (m_track.loop)
-                m_state = playerRestart;
+            if (m_track.single)
+                return;
+            // Move to next track
+            m_track.selected++;
+            if (m_track.selected > m_track.songs)
+                m_track.selected = 1;
+            if (m_track.selected == m_track.first)
+                return;
+            m_state = playerRestart;
+            break;
         }
+        if (m_track.loop)
+            m_state = playerRestart;
     }
-
-    // Units in C64 clock cycles
-    m_context->schedule (*this, 900000, EVENT_CLOCK_PHI1);
 }
 
 
@@ -777,33 +775,48 @@ void ConsolePlayer::decodeKeys ()
         break;
 
         case A_TOGGLE_VOICE1:
-            v1mute = !v1mute;
-            m_engine.mute(0, 0, v1mute);
+            vMute[0] = !vMute[0];
+            m_engine.mute(0, 0, vMute[0]);
         break;
 
         case A_TOGGLE_VOICE2:
-            v2mute = !v2mute;
-            m_engine.mute(0, 1, v2mute);
+            vMute[1] = !vMute[1];
+            m_engine.mute(0, 1, vMute[1]);
         break;
 
         case A_TOGGLE_VOICE3:
-            v3mute = !v3mute;
-            m_engine.mute(0, 2, v3mute);
+            vMute[2] = !vMute[2];
+            m_engine.mute(0, 2, vMute[2]);
         break;
 
         case A_TOGGLE_VOICE4:
-            v4mute = !v4mute;
-            m_engine.mute(1, 0, v4mute);
+            vMute[3] = !vMute[3];
+            m_engine.mute(1, 0, vMute[3]);
         break;
 
         case A_TOGGLE_VOICE5:
-            v5mute = !v5mute;
-            m_engine.mute(1, 1, v5mute);
+            vMute[4] = !vMute[4];
+            m_engine.mute(1, 1, vMute[4]);
         break;
 
         case A_TOGGLE_VOICE6:
-            v6mute = !v6mute;
-            m_engine.mute(1, 2, v6mute);
+            vMute[5] = !vMute[5];
+            m_engine.mute(1, 2, vMute[5]);
+        break;
+
+        case A_TOGGLE_VOICE7:
+            vMute[6] = !vMute[6];
+            m_engine.mute(2, 0, vMute[6]);
+        break;
+
+        case A_TOGGLE_VOICE8:
+            vMute[7] = !vMute[7];
+            m_engine.mute(2, 1, vMute[7]);
+        break;
+
+        case A_TOGGLE_VOICE9:
+            vMute[8] = !vMute[8];
+            m_engine.mute(2, 2, vMute[8]);
         break;
 
         case A_TOGGLE_FILTER:
