@@ -23,6 +23,8 @@
 
 #include <string>
 
+#include "ini/types.h"
+
 class utils
 {
 public:
@@ -30,15 +32,15 @@ public:
 
 private:
 #ifdef _WIN32
-    static std::string getPath();
+    static SID_STRING getPath();
 #else
-    static std::string getPath(const char* id, const char* def);
+    static SID_STRING getPath(const char* id, const char* def);
 #endif
 
 public:
-    static std::string getDataPath();
+    static SID_STRING getDataPath();
     
-    static std::string getConfigPath();
+    static SID_STRING getConfigPath();
 };
 
 #endif
